summaryrefslogtreecommitdiffstats
path: root/src/gui/listboxtext.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-02 06:40:27 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-02 06:40:27 +0000
commit2595a15ebeb6fc46b7cb241d01ec0c2460ec2111 (patch)
tree18a8f0f4ac5a86dacfa74c3537551ec39bc85e75 /src/gui/listboxtext.h
parent1d90725a4001fab9d3922b2cbcceeee5e2d1686f (diff)
downloadtellico-2595a15ebeb6fc46b7cb241d01ec0c2460ec2111.tar.gz
tellico-2595a15ebeb6fc46b7cb241d01ec0c2460ec2111.zip
TQt4 port tellico
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/tellico@1239054 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/gui/listboxtext.h')
-rw-r--r--src/gui/listboxtext.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/gui/listboxtext.h b/src/gui/listboxtext.h
index 3cfe2db..03edc95 100644
--- a/src/gui/listboxtext.h
+++ b/src/gui/listboxtext.h
@@ -14,31 +14,31 @@
#ifndef TELLICO_GUI_LISTBOXTEXT_H
#define TELLICO_GUI_LISTBOXTEXT_H
-#include <qlistbox.h>
+#include <tqlistbox.h>
namespace Tellico {
namespace GUI {
/**
* ListBoxText subclasses QListBoxText so that @ref setText() can be made public,
* and the font color can be changed
*
* @author Robby Stephenson
*/
-class ListBoxText : public QListBoxText {
+class ListBoxText : public TQListBoxText {
public:
- ListBoxText(QListBox* listbox, const QString& text);
- ListBoxText(QListBox* listbox, const QString& text, QListBoxItem* after);
+ ListBoxText(TQListBox* listbox, const TQString& text);
+ ListBoxText(TQListBox* listbox, const TQString& text, TQListBoxItem* after);
- virtual int width(const QListBox* box) const;
- virtual int height(const QListBox* box) const;
+ virtual int width(const TQListBox* box) const;
+ virtual int height(const TQListBox* box) const;
bool isColored() const { return m_colored; }
void setColored(bool colored);
- void setText(const QString& text);
+ void setText(const TQString& text);
protected:
- virtual void paint(QPainter* painter);
+ virtual void paint(TQPainter* painter);
private:
bool m_colored;
@@ -14,31 +14,31 @@
namespace GUI {
/**
- * ListBoxText subclasses QListBoxText so that @ref setText() can be made public,
+ * ListBoxText subclasses TQListBoxText so that @ref setText() can be made public,
* and the font color can be changed
*